@@ -175,7 +175,7 @@ negbin <- function(formula, random, data, phi.ini = NULL, warnings = FALSE, na.a
   msg <- if(!is.null(res$message)) res$message else character(0)
 
   if(code != 0)
-    warning("\Possible convergence problem. Optimization process code: ", code, " (see ?optim).\n")
+    warning("\nPossible convergence problem. Optimization process code: ", code, " (see ?optim).\n")
 
 # Output
   new(Class = "glimML", CALL = CALL, link = "log", method = "NB", data = data, formula = formula, random = random, 
